@@ -1,17 +1,30 @@
-webs2array <- function(...){
+webs2array <- function(x, ...){
 	# function to put several webs into an array, blowing the dimensions up to the union of species
 	# makes sense only for webs featuring overlapping communities!
-	webinput <- substitute(list(...))
-	web.names <- as.character(webinput)[-1L]
-	webs <- eval(webinput)
-  if (is(webs[[1]], "list")){
-    webs <- webs[[1]]
-    web.names <- names(webs)
-    if (is.null(web.names)) {web.names <- paste0("web",1:length(webs))}
-  }
 	
+  if (is(x, "list")) { 
+    # do the list stuff:
+    webs <- x
+    web.names <- names(x)
+    if (is.null(web.names)) {web.names <- paste0("web", 1:length(webs))}
+    # print("Since you provided a list for x, anything in ... will be ignored.")
+  } else {
+    # combine all ... and x into a single list:
+    webinput <- substitute(list(x, ...))
+    web.names <- as.character(webinput)[-1L]
+    webs <- eval(webinput)
+    #if (is(webs[[1]], "list")){
+    #    webs <- webs[[1]]
+    #    web.names <- names(webs)
+    #    if (is.null(web.names)) {web.names <- paste0("web", 1:length(webs))}
+    #}
+    
+  }
+
 	if (length(webs) < 2) stop("Please provide more than one web as input!")
 	
+	
+	
 	all.names.HL <- sort(unique(unlist(lapply(webs, colnames)))) # this was sapply before, which caused duplicate names (unique didn't work)
 	all.names.LL <- sort(unique(unlist(lapply(webs, rownames)))) # was sapply before
 	
